@@ -5,10 +5,12 @@ Usage:
   %s [options] <reversed URL prefix>
 """
 
+import inspect
 import sys
 
 import gflags
 
+from commoncrawlindex import cli
 from commoncrawlindex import index
 
 FLAGS = gflags.FLAGS
@@ -20,18 +22,9 @@ gflags.DEFINE_boolean(
   short_name='m')
 
 
-def main():
-  try:
-    argv = FLAGS(sys.argv)
-  except gflags.FlagsError, e:
-    sys.stderr.write('Error: %s\n%s%s\n' % (
-        e,
-        sys.modules[__name__].__doc__.replace('%s', sys.argv[0]),
-        FLAGS))
-    sys.exit(2)
+def main(argv):
   if len(argv) != 2:
-    sys.stderr.write('Error: Wrong number of arguments.\n')
-    sys.exit(1)
+    raise cli.UsageError('Wrong number of arguments.')
   index_reader = index.open_index_reader()
   try:
     for url, d in index_reader.itemsiter(argv[1]):
@@ -43,5 +36,8 @@ def main():
     pass
 
 
+def cli_main():
+  cli.App(main=main, usage=inspect.getmodule(main).__doc__).run()
+
 if __name__ == '__main__':
-  main()
+  cli_main()
